@@ -171,7 +171,7 @@ ALLOWED_VALUES = {
     "fsx_ssd_throughput": FSX_SSD_THROUGHPUT,
     "fsx_hdd_throughput": FSX_HDD_THROUGHPUT,
     "architectures": SUPPORTED_ARCHITECTURES,
-    "fsx_auto_import_policy": ["NEW", "NEW_CHANGED"],
+    "fsx_auto_import_policy": ["NEW", "NEW_CHANGED", "NEW_CHANGED_DELETED"],
     "fsx_storage_type": ["SSD", "HDD"],
     "fsx_drive_cache_type": ["READ"],
     "fsx_data_compression_type": ["LZ4"]
@@ -238,7 +238,6 @@ SCALING = {
         "scaledown_idletime": {
             "type": IntCfnParam,
             "default": 10,
-            "cfn_param_mapping": "ScaleDownIdleTime",
             "update_policy": UpdatePolicy.COMPUTE_FLEET_STOP
         },
         "_scaledown_idletime": {
@@ -809,7 +808,7 @@ CLUSTER_COMMON_PARAMS = [
     }),
     ("scheduler", {
         "cfn_param_mapping": "Scheduler",
-        "allowed_values": ["awsbatch", "sge", "slurm", "torque"],
+        "allowed_values": ["awsbatch", "slurm"],
         "validators": [scheduler_validator],
         "required": True,
         "update_policy": UpdatePolicy.UNSUPPORTED
@@ -950,7 +949,7 @@ CLUSTER_COMMON_PARAMS = [
         # There is no cfn_param_mapping because it's not converted to a CFN Input parameter
         "type": TagsParam,
         "validators": [tags_validator],
-        "update_policy": UpdatePolicy.COMPUTE_FLEET_STOP,
+        "update_policy": UpdatePolicy.UNSUPPORTED,
     }),
     ("custom_chef_cookbook", {
         "cfn_param_mapping": "CustomChefCookbook",
